# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `FilesetEntry.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Fileset' not in _M_omero.model.__dict__:
    _M_omero.model._t_Fileset = IcePy.declareClass('::omero::model::Fileset')
    _M_omero.model._t_FilesetPrx = IcePy.declareProxy('::omero::model::Fileset')

if 'OriginalFile' not in _M_omero.model.__dict__:
    _M_omero.model._t_OriginalFile = IcePy.declareClass('::omero::model::OriginalFile')
    _M_omero.model._t_OriginalFilePrx = IcePy.declareProxy('::omero::model::OriginalFile')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'FilesetEntry' not in _M_omero.model.__dict__:
    _M_omero.model.FilesetEntry = Ice.createTempClass()
    class FilesetEntry(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _fileset=None, _originalFile=None, _clientPath=None):
            if Ice.getType(self) == _M_omero.model.FilesetEntry:
                raise RuntimeError('omero.model.FilesetEntry is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._fileset = _fileset
            self._originalFile = _originalFile
            self._clientPath = _clientPath

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::FilesetEntry', '::omero::model::IObject')

        def ice_id(self, current=None):
            return '::omero::model::FilesetEntry'

        def ice_staticId():
            return '::omero::model::FilesetEntry'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getFileset(self, current=None):
            pass

        def setFileset(self, theFileset, current=None):
            pass

        def getOriginalFile(self, current=None):
            pass

        def setOriginalFile(self, theOriginalFile, current=None):
            pass

        def getClientPath(self, current=None):
            pass

        def setClientPath(self, theClientPath, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_FilesetEntry)

        __repr__ = __str__

    _M_omero.model.FilesetEntryPrx = Ice.createTempClass()
    class FilesetEntryPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.FilesetEntry._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.FilesetEntry._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.FilesetEntry._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.FilesetEntry._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.FilesetEntry._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.FilesetEntry._op_setVersion.end(self, _r)

        def getFileset(self, _ctx=None):
            return _M_omero.model.FilesetEntry._op_getFileset.invoke(self, ((), _ctx))

        def begin_getFileset(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.FilesetEntry._op_getFileset.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getFileset(self, _r):
            return _M_omero.model.FilesetEntry._op_getFileset.end(self, _r)

        def setFileset(self, theFileset, _ctx=None):
            return _M_omero.model.FilesetEntry._op_setFileset.invoke(self, ((theFileset, ), _ctx))

        def begin_setFileset(self, theFileset, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.FilesetEntry._op_setFileset.begin(self, ((theFileset, ), _response, _ex, _sent, _ctx))

        def end_setFileset(self, _r):
            return _M_omero.model.FilesetEntry._op_setFileset.end(self, _r)

        def getOriginalFile(self, _ctx=None):
            return _M_omero.model.FilesetEntry._op_getOriginalFile.invoke(self, ((), _ctx))

        def begin_getOriginalFile(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.FilesetEntry._op_getOriginalFile.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getOriginalFile(self, _r):
            return _M_omero.model.FilesetEntry._op_getOriginalFile.end(self, _r)

        def setOriginalFile(self, theOriginalFile, _ctx=None):
            return _M_omero.model.FilesetEntry._op_setOriginalFile.invoke(self, ((theOriginalFile, ), _ctx))

        def begin_setOriginalFile(self, theOriginalFile, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.FilesetEntry._op_setOriginalFile.begin(self, ((theOriginalFile, ), _response, _ex, _sent, _ctx))

        def end_setOriginalFile(self, _r):
            return _M_omero.model.FilesetEntry._op_setOriginalFile.end(self, _r)

        def getClientPath(self, _ctx=None):
            return _M_omero.model.FilesetEntry._op_getClientPath.invoke(self, ((), _ctx))

        def begin_getClientPath(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.FilesetEntry._op_getClientPath.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getClientPath(self, _r):
            return _M_omero.model.FilesetEntry._op_getClientPath.end(self, _r)

        def setClientPath(self, theClientPath, _ctx=None):
            return _M_omero.model.FilesetEntry._op_setClientPath.invoke(self, ((theClientPath, ), _ctx))

        def begin_setClientPath(self, theClientPath, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.FilesetEntry._op_setClientPath.begin(self, ((theClientPath, ), _response, _ex, _sent, _ctx))

        def end_setClientPath(self, _r):
            return _M_omero.model.FilesetEntry._op_setClientPath.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.FilesetEntryPrx.ice_checkedCast(proxy, '::omero::model::FilesetEntry', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.FilesetEntryPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::FilesetEntry'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_FilesetEntryPrx = IcePy.defineProxy('::omero::model::FilesetEntry', FilesetEntryPrx)

    _M_omero.model._t_FilesetEntry = IcePy.declareClass('::omero::model::FilesetEntry')

    _M_omero.model._t_FilesetEntry = IcePy.defineClass('::omero::model::FilesetEntry', FilesetEntry, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_fileset', (), _M_omero.model._t_Fileset, False, 0),
        ('_originalFile', (), _M_omero.model._t_OriginalFile, False, 0),
        ('_clientPath', (), _M_omero._t_RString, False, 0)
    ))
    FilesetEntry._ice_type = _M_omero.model._t_FilesetEntry

    FilesetEntry._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    FilesetEntry._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    FilesetEntry._op_getFileset = IcePy.Operation('getFileset', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Fileset, False, 0), ())
    FilesetEntry._op_setFileset = IcePy.Operation('setFileset', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Fileset, False, 0),), (), None, ())
    FilesetEntry._op_getOriginalFile = IcePy.Operation('getOriginalFile', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_OriginalFile, False, 0), ())
    FilesetEntry._op_setOriginalFile = IcePy.Operation('setOriginalFile', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFile, False, 0),), (), None, ())
    FilesetEntry._op_getClientPath = IcePy.Operation('getClientPath', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    FilesetEntry._op_setClientPath = IcePy.Operation('setClientPath', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())

    _M_omero.model.FilesetEntry = FilesetEntry
    del FilesetEntry

    _M_omero.model.FilesetEntryPrx = FilesetEntryPrx
    del FilesetEntryPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (C) 2014 Glencoe Software, Inc. All Rights Reserved.
# Use is subject to license terms supplied in LICENSE.txt
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

"""
Multiple inheritance class that can be re-used by all of
the unit implementations.
"""


from builtins import str
from builtins import object
class UnitBase(object):

    def _base_string(self, v, u):
        if v is not None:
            return "%s %s" % (v, str(u))
        return ""



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `IRenderingSettings.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_ModelF_ice
import omero_ServicesF_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Included module omero.grid
_M_omero.grid = Ice.openModule('omero.grid')

# Start of module omero
__name__ = 'omero'

# Start of module omero.api
__name__ = 'omero.api'

if 'IRenderingSettings' not in _M_omero.api.__dict__:
    _M_omero.api.IRenderingSettings = Ice.createTempClass()
    class IRenderingSettings(_M_omero.api.ServiceInterface):
        """
        Provides method to apply rendering settings to a collection of
        images.
        All methods will receive the id of the pixels set to copy the
        rendering settings from.
        """
        def __init__(self):
            if Ice.getType(self) == _M_omero.api.IRenderingSettings:
                raise RuntimeError('omero.api.IRenderingSettings is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::api::IRenderingSettings', '::omero::api::ServiceInterface')

        def ice_id(self, current=None):
            return '::omero::api::IRenderingSettings'

        def ice_staticId():
            return '::omero::api::IRenderingSettings'
        ice_staticId = staticmethod(ice_staticId)

        def sanityCheckPixels_async(self, _cb, pFrom, pTo, current=None):
            """
            Checks if the specified sets of pixels are compatible.
            Returns true if the pixels set is valid,
            false otherwise.
            Arguments:
            _cb -- The asynchronous callback object.
            pFrom -- The pixels set to copy the settings from.
            pTo -- The pixels set to copy the settings to.
            current -- The Current object for the invocation.
            """
            pass

        def getRenderingSettings_async(self, _cb, pixelsId, current=None):
            """
            Returns the default rendering settings for a given pixels
            for the current user.
            Arguments:
            _cb -- The asynchronous callback object.
            pixelsId -- The Id of the Pixels
            current -- The Current object for the invocation.
            Throws:
            ValidationException -- if the image qualified by imageId is unlocatable.
            """
            pass

        def createNewRenderingDef_async(self, _cb, pixels, current=None):
            """
            Creates a new rendering definition object along with its
            sub-objects.
            Arguments:
            _cb -- The asynchronous callback object.
            pixels -- The Pixels set to link to the rendering definition.
            current -- The Current object for the invocation.
            """
            pass

        def resetDefaults_async(self, _cb, _def, pixels, current=None):
            """
            Resets the given rendering settings to those that are
            specified by the rendering engine intelligent pretty
            good image (PG) logic for the pixels set linked to that
            set of rendering settings. NOTE: This method should
            only be used to reset a rendering definition that has been
            retrieved via {@code getRenderingSettings} as it
            relies on certain objects being loaded. The rendering
            settings are saved upon completion.
            Arguments:
            _cb -- The asynchronous callback object.
            _def -- A RenderingDef to reset. It is expected that def.pixels will be unloaded and that the actual linked Pixels set will be provided in the pixels argument.
            pixels -- The Pixels set for def.
            current -- The Current object for the invocation.
            """
            pass

        def resetDefaultsNoSave_async(self, _cb, _def, pixels, current=None):
            """
            Resets the given rendering settings to those that are
            specified by the rendering engine intelligent pretty
            good image (PG) logic for the pixels set linked to that
            set of rendering settings. NOTE: This method should
            only be used to reset a rendering definition that has been
            retrieved via {@code getRenderingSettings(long)} as it
            relies on certain objects being loaded. The rendering
            settings are not saved.
            Arguments:
            _cb -- The asynchronous callback object.
            _def -- A RenderingDef to reset. It is expected that def.pixels will be unloaded and that the actual linked Pixels set will be provided in the pixels argument.
            pixels -- The Pixels set for def.
            current -- The Current object for the invocation.
            """
            pass

        def resetDefaultsInImage_async(self, _cb, imageId, current=None):
            """
            Resets an image's default rendering settings back to those
            that are specified by the rendering engine intelligent
            pretty good image (PG) logic.
            Arguments:
            _cb -- The asynchronous callback object.
            imageId -- The Id of the Image.
            current -- The Current object for the invocation.
            Throws:
            ValidationException -- if the image qualified by imageId is unlocatable.
            """
            pass

        def resetDefaultsForPixels_async(self, _cb, pixelsId, current=None):
            """
            Resets a Pixels' default rendering settings back to those
            that are specified by the rendering engine intelligent
            pretty good image (PG) logic.
            Arguments:
            _cb -- The asynchronous callback object.
            pixelsId -- The Id of the Pixels.
            current -- The Current object for the invocation.
            Throws:
            ValidationException -- if the Pixels qualified by pixelsId is unlocatable.
            """
            pass

        def resetDefaultsInDataset_async(self, _cb, datasetId, current=None):
            """
            Resets a dataset's rendering settings back to those that
            are specified by the rendering engine intelligent pretty
            good image (PG) logic.
            Arguments:
            _cb -- The asynchronous callback object.
            datasetId -- The Id of the Dataset.
            current -- The Current object for the invocation.
            Throws:
            ValidationException -- if the image qualified by datasetId is not locatable.
            """
            pass

        def resetDefaultsInSet_async(self, _cb, type, nodeIds, current=None):
            """
            Resets a rendering settings back to one or many containers
            that are specified by the rendering engine intelligent
            pretty good image (PG) logic. Supported container
            types are:
            omero.model.Project
            omero.model.Dataset
            omero.model.Image
            omero.model.Plate
            omero.model.Pixels
            Arguments:
            _cb -- The asynchronous callback object.
            type -- The type of nodes to handle.
            nodeIds -- Ids of the node type.
            current -- The Current object for the invocation.
            Throws:
            ValidationException -- if an illegal type is used.
            """
            pass

        def resetDefaultsByOwnerInSet_async(self, _cb, type, nodeIds, current=None):
            """
            Resets the rendering settings of a given group of
            containers based on the owner's (essentially a copy).
            Supported container types are:
            omero.model.Project
            omero.model.Dataset
            omero.model.Image
            omero.model.Plate
            omero.model.Pixels
            Arguments:
            _cb -- The asynchronous callback object.
            type -- The type of nodes to handle.
            nodeIds -- Ids of the node type.
            current -- The Current object for the invocation.
            Throws:
            ValidationException -- if an illegal type is used.
            """
            pass

        def resetMinMaxInSet_async(self, _cb, type, nodeIds, current=None):
            """
            Resets a the channel windows for one or many containers
            back to their global minimum and global maximum for the
            channel. Supported container types are:
            omero.model.Project
            omero.model.Dataset
            omero.model.Image
            omero.model.Plate
            omero.model.Pixels
            Arguments:
            _cb -- The asynchronous callback object.
            type -- The type of nodes to handle.
            nodeIds -- Ids of the node type.
            current -- The Current object for the invocation.
            Throws:
            ValidationException -- if an illegal type is used.
            """
            pass

        def applySettingsToSet_async(self, _cb, _from, toType, nodeIds, current=None):
            """
            Applies rendering settings to one or many containers. If a
            container such as Dataset is to be copied to, all images
            within that Dataset will have the rendering settings
            applied. Supported container types are:
            omero.model.Project
            omero.model.Dataset
            omero.model.Image
            omero.model.Plate
            omero.model.Screen
            omero.model.Pixels
            Arguments:
            _cb -- The asynchronous callback object.
            _from -- The Id of the pixels set to copy the rendering settings from.
            toType -- The type of nodes to handle.
            nodeIds -- Ids of the node type.
            current -- The Current object for the invocation.
            Throws:
            ValidationException -- if an illegal type is used.
            """
            pass

        def applySettingsToProject_async(self, _cb, _from, to, current=None):
            """
            Applies rendering settings to all images in all Datasets of
            a given Project.
            Arguments:
            _cb -- The asynchronous callback object.
            _from -- The Id of the pixels set to copy the rendering settings from.
            to -- The Id of the project container to apply settings to.
            current -- The Current object for the invocation.
            Throws:
            ValidationException -- if the rendering settings from is not locatable or the project to is not locatable.
            """
            pass

        def applySettingsToDataset_async(self, _cb, _from, to, current=None):
            """
            Applies rendering settings to all images in a given Dataset.
            Arguments:
            _cb -- The asynchronous callback object.
            _from -- The Id of the pixels set to copy the rendering settings from.
            to -- The Id of the dataset container to apply settings to.
            current -- The Current object for the invocation.
            Throws:
            ValidationException -- if the rendering settings from is not locatable or the dataset to is not locatable.
            """
            pass

        def applySettingsToImages_async(self, _cb, _from, to, current=None):
            """
            Applies rendering settings to a given Image.
            Arguments:
            _cb -- The asynchronous callback object.
            _from -- The Id of the pixels set to copy the rendering settings from.
            to -- The Id of the image container to apply settings to.
            current -- The Current object for the invocation.
            Throws:
            ValidationException -- if the rendering settings from is not locatable or the image to is not locatable.
            """
            pass

        def applySettingsToImage_async(self, _cb, _from, to, current=None):
            """
            Applies rendering settings to a given Image.
            Arguments:
            _cb -- The asynchronous callback object.
            _from -- The Id of the pixels set to copy the rendering settings from.
            to -- The Id of the image container to apply settings to.
            current -- The Current object for the invocation.
            Throws:
            ValidationException -- if the rendering settings from is not locatable or the image to is not locatable.
            """
            pass

        def applySettingsToPixels_async(self, _cb, _from, to, current=None):
            """
            Applies rendering settings to a given Pixels.
            Arguments:
            _cb -- The asynchronous callback object.
            _from -- The Id of the pixels set to copy the rendering settings from.
            to -- The Id of the pixels container to apply settings to.
            current -- The Current object for the invocation.
            Throws:
            ValidationException -- if the rendering settings from is not locatable or the pixelsto is not locatable.
            """
            pass

        def setOriginalSettingsInImage_async(self, _cb, imageId, current=None):
            """
            Resets an image's default rendering settings back to
            channel global minimum and maximum.
            Arguments:
            _cb -- The asynchronous callback object.
            imageId -- The Id of the Image.
            current -- The Current object for the invocation.
            Throws:
            ValidationException -- if the image qualified by imageId is not locatable.
            """
            pass

        def setOriginalSettingsForPixels_async(self, _cb, pixelsId, current=None):
            """
            Resets an Pixels' default rendering settings back to
            channel global minimum and maximum.
            Arguments:
            _cb -- The asynchronous callback object.
            pixelsId -- The Id of the Pixels set.
            current -- The Current object for the invocation.
            Throws:
            ValidationException -- if the image qualified by pixelsId is not locatable.
            """
            pass

        def setOriginalSettingsInDataset_async(self, _cb, datasetId, current=None):
            """
            Resets a dataset's rendering settings back to channel global
            minimum and maximum.
            Arguments:
            _cb -- The asynchronous callback object.
            datasetId -- The id of the dataset to handle.
            current -- The Current object for the invocation.
            Throws:
            ValidationException -- if the image qualified by datasetId is not locatable.
            """
            pass

        def setOriginalSettingsInSet_async(self, _cb, type, nodeIds, current=None):
            """
            Resets a rendering settings back to channel global minimum
            and maximum for the specified containers. Supported
            container types are:
            omero.model.Project
            omero.model.Dataset
            omero.model.Image
            omero.model.Plate
            omero.model.Pixels
            Arguments:
            _cb -- The asynchronous callback object.
            type -- The type of nodes to handle.
            nodeIds -- Ids of the node type.
            current -- The Current object for the invocation.
            Throws:
            ValidationException -- if an illegal type is used.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.api._t_IRenderingSettings)

        __repr__ = __str__

    _M_omero.api.IRenderingSettingsPrx = Ice.createTempClass()
    class IRenderingSettingsPrx(_M_omero.api.ServiceInterfacePrx):

        """
        Checks if the specified sets of pixels are compatible.
        Returns true if the pixels set is valid,
        false otherwise.
        Arguments:
        pFrom -- The pixels set to copy the settings from.
        pTo -- The pixels set to copy the settings to.
        _ctx -- The request context for the invocation.
        Returns: See above.
        """
        def sanityCheckPixels(self, pFrom, pTo, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_sanityCheckPixels.invoke(self, ((pFrom, pTo), _ctx))

        """
        Checks if the specified sets of pixels are compatible.
        Returns true if the pixels set is valid,
        false otherwise.
        Arguments:
        pFrom -- The pixels set to copy the settings from.
        pTo -- The pixels set to copy the settings to.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_sanityCheckPixels(self, pFrom, pTo, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_sanityCheckPixels.begin(self, ((pFrom, pTo), _response, _ex, _sent, _ctx))

        """
        Checks if the specified sets of pixels are compatible.
        Returns true if the pixels set is valid,
        false otherwise.
        Arguments:
        pFrom -- The pixels set to copy the settings from.
        pTo -- The pixels set to copy the settings to.
        Returns: See above.
        """
        def end_sanityCheckPixels(self, _r):
            return _M_omero.api.IRenderingSettings._op_sanityCheckPixels.end(self, _r)

        """
        Returns the default rendering settings for a given pixels
        for the current user.
        Arguments:
        pixelsId -- The Id of the Pixels
        _ctx -- The request context for the invocation.
        Returns: See above.
        Throws:
        ValidationException -- if the image qualified by imageId is unlocatable.
        """
        def getRenderingSettings(self, pixelsId, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_getRenderingSettings.invoke(self, ((pixelsId, ), _ctx))

        """
        Returns the default rendering settings for a given pixels
        for the current user.
        Arguments:
        pixelsId -- The Id of the Pixels
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getRenderingSettings(self, pixelsId, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_getRenderingSettings.begin(self, ((pixelsId, ), _response, _ex, _sent, _ctx))

        """
        Returns the default rendering settings for a given pixels
        for the current user.
        Arguments:
        pixelsId -- The Id of the Pixels
        Returns: See above.
        Throws:
        ValidationException -- if the image qualified by imageId is unlocatable.
        """
        def end_getRenderingSettings(self, _r):
            return _M_omero.api.IRenderingSettings._op_getRenderingSettings.end(self, _r)

        """
        Creates a new rendering definition object along with its
        sub-objects.
        Arguments:
        pixels -- The Pixels set to link to the rendering definition.
        _ctx -- The request context for the invocation.
        Returns: A new, blank rendering definition and sub-objects. NOTE: the linked Pixels has been unloaded.
        """
        def createNewRenderingDef(self, pixels, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_createNewRenderingDef.invoke(self, ((pixels, ), _ctx))

        """
        Creates a new rendering definition object along with its
        sub-objects.
        Arguments:
        pixels -- The Pixels set to link to the rendering definition.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_createNewRenderingDef(self, pixels, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_createNewRenderingDef.begin(self, ((pixels, ), _response, _ex, _sent, _ctx))

        """
        Creates a new rendering definition object along with its
        sub-objects.
        Arguments:
        pixels -- The Pixels set to link to the rendering definition.
        Returns: A new, blank rendering definition and sub-objects. NOTE: the linked Pixels has been unloaded.
        """
        def end_createNewRenderingDef(self, _r):
            return _M_omero.api.IRenderingSettings._op_createNewRenderingDef.end(self, _r)

        """
        Resets the given rendering settings to those that are
        specified by the rendering engine intelligent pretty
        good image (PG) logic for the pixels set linked to that
        set of rendering settings. NOTE: This method should
        only be used to reset a rendering definition that has been
        retrieved via {@code getRenderingSettings} as it
        relies on certain objects being loaded. The rendering
        settings are saved upon completion.
        Arguments:
        _def -- A RenderingDef to reset. It is expected that def.pixels will be unloaded and that the actual linked Pixels set will be provided in the pixels argument.
        pixels -- The Pixels set for def.
        _ctx -- The request context for the invocation.
        """
        def resetDefaults(self, _def, pixels, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_resetDefaults.invoke(self, ((_def, pixels), _ctx))

        """
        Resets the given rendering settings to those that are
        specified by the rendering engine intelligent pretty
        good image (PG) logic for the pixels set linked to that
        set of rendering settings. NOTE: This method should
        only be used to reset a rendering definition that has been
        retrieved via {@code getRenderingSettings} as it
        relies on certain objects being loaded. The rendering
        settings are saved upon completion.
        Arguments:
        _def -- A RenderingDef to reset. It is expected that def.pixels will be unloaded and that the actual linked Pixels set will be provided in the pixels argument.
        pixels -- The Pixels set for def.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_resetDefaults(self, _def, pixels, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_resetDefaults.begin(self, ((_def, pixels), _response, _ex, _sent, _ctx))

        """
        Resets the given rendering settings to those that are
        specified by the rendering engine intelligent pretty
        good image (PG) logic for the pixels set linked to that
        set of rendering settings. NOTE: This method should
        only be used to reset a rendering definition that has been
        retrieved via {@code getRenderingSettings} as it
        relies on certain objects being loaded. The rendering
        settings are saved upon completion.
        Arguments:
        _def -- A RenderingDef to reset. It is expected that def.pixels will be unloaded and that the actual linked Pixels set will be provided in the pixels argument.
        pixels -- The Pixels set for def.
        """
        def end_resetDefaults(self, _r):
            return _M_omero.api.IRenderingSettings._op_resetDefaults.end(self, _r)

        """
        Resets the given rendering settings to those that are
        specified by the rendering engine intelligent pretty
        good image (PG) logic for the pixels set linked to that
        set of rendering settings. NOTE: This method should
        only be used to reset a rendering definition that has been
        retrieved via {@code getRenderingSettings(long)} as it
        relies on certain objects being loaded. The rendering
        settings are not saved.
        Arguments:
        _def -- A RenderingDef to reset. It is expected that def.pixels will be unloaded and that the actual linked Pixels set will be provided in the pixels argument.
        pixels -- The Pixels set for def.
        _ctx -- The request context for the invocation.
        Returns: def with the rendering settings reset.
        """
        def resetDefaultsNoSave(self, _def, pixels, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_resetDefaultsNoSave.invoke(self, ((_def, pixels), _ctx))

        """
        Resets the given rendering settings to those that are
        specified by the rendering engine intelligent pretty
        good image (PG) logic for the pixels set linked to that
        set of rendering settings. NOTE: This method should
        only be used to reset a rendering definition that has been
        retrieved via {@code getRenderingSettings(long)} as it
        relies on certain objects being loaded. The rendering
        settings are not saved.
        Arguments:
        _def -- A RenderingDef to reset. It is expected that def.pixels will be unloaded and that the actual linked Pixels set will be provided in the pixels argument.
        pixels -- The Pixels set for def.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_resetDefaultsNoSave(self, _def, pixels, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_resetDefaultsNoSave.begin(self, ((_def, pixels), _response, _ex, _sent, _ctx))

        """
        Resets the given rendering settings to those that are
        specified by the rendering engine intelligent pretty
        good image (PG) logic for the pixels set linked to that
        set of rendering settings. NOTE: This method should
        only be used to reset a rendering definition that has been
        retrieved via {@code getRenderingSettings(long)} as it
        relies on certain objects being loaded. The rendering
        settings are not saved.
        Arguments:
        _def -- A RenderingDef to reset. It is expected that def.pixels will be unloaded and that the actual linked Pixels set will be provided in the pixels argument.
        pixels -- The Pixels set for def.
        Returns: def with the rendering settings reset.
        """
        def end_resetDefaultsNoSave(self, _r):
            return _M_omero.api.IRenderingSettings._op_resetDefaultsNoSave.end(self, _r)

        """
        Resets an image's default rendering settings back to those
        that are specified by the rendering engine intelligent
        pretty good image (PG) logic.
        Arguments:
        imageId -- The Id of the Image.
        _ctx -- The request context for the invocation.
        Throws:
        ValidationException -- if the image qualified by imageId is unlocatable.
        """
        def resetDefaultsInImage(self, imageId, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_resetDefaultsInImage.invoke(self, ((imageId, ), _ctx))

        """
        Resets an image's default rendering settings back to those
        that are specified by the rendering engine intelligent
        pretty good image (PG) logic.
        Arguments:
        imageId -- The Id of the Image.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_resetDefaultsInImage(self, imageId, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_resetDefaultsInImage.begin(self, ((imageId, ), _response, _ex, _sent, _ctx))

        """
        Resets an image's default rendering settings back to those
        that are specified by the rendering engine intelligent
        pretty good image (PG) logic.
        Arguments:
        imageId -- The Id of the Image.
        Throws:
        ValidationException -- if the image qualified by imageId is unlocatable.
        """
        def end_resetDefaultsInImage(self, _r):
            return _M_omero.api.IRenderingSettings._op_resetDefaultsInImage.end(self, _r)

        """
        Resets a Pixels' default rendering settings back to those
        that are specified by the rendering engine intelligent
        pretty good image (PG) logic.
        Arguments:
        pixelsId -- The Id of the Pixels.
        _ctx -- The request context for the invocation.
        Throws:
        ValidationException -- if the Pixels qualified by pixelsId is unlocatable.
        """
        def resetDefaultsForPixels(self, pixelsId, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_resetDefaultsForPixels.invoke(self, ((pixelsId, ), _ctx))

        """
        Resets a Pixels' default rendering settings back to those
        that are specified by the rendering engine intelligent
        pretty good image (PG) logic.
        Arguments:
        pixelsId -- The Id of the Pixels.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_resetDefaultsForPixels(self, pixelsId, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_resetDefaultsForPixels.begin(self, ((pixelsId, ), _response, _ex, _sent, _ctx))

        """
        Resets a Pixels' default rendering settings back to those
        that are specified by the rendering engine intelligent
        pretty good image (PG) logic.
        Arguments:
        pixelsId -- The Id of the Pixels.
        Throws:
        ValidationException -- if the Pixels qualified by pixelsId is unlocatable.
        """
        def end_resetDefaultsForPixels(self, _r):
            return _M_omero.api.IRenderingSettings._op_resetDefaultsForPixels.end(self, _r)

        """
        Resets a dataset's rendering settings back to those that
        are specified by the rendering engine intelligent pretty
        good image (PG) logic.
        Arguments:
        datasetId -- The Id of the Dataset.
        _ctx -- The request context for the invocation.
        Returns: A java.util.Set of image IDs that have had their rendering settings reset.
        Throws:
        ValidationException -- if the image qualified by datasetId is not locatable.
        """
        def resetDefaultsInDataset(self, datasetId, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_resetDefaultsInDataset.invoke(self, ((datasetId, ), _ctx))

        """
        Resets a dataset's rendering settings back to those that
        are specified by the rendering engine intelligent pretty
        good image (PG) logic.
        Arguments:
        datasetId -- The Id of the Dataset.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_resetDefaultsInDataset(self, datasetId, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_resetDefaultsInDataset.begin(self, ((datasetId, ), _response, _ex, _sent, _ctx))

        """
        Resets a dataset's rendering settings back to those that
        are specified by the rendering engine intelligent pretty
        good image (PG) logic.
        Arguments:
        datasetId -- The Id of the Dataset.
        Returns: A java.util.Set of image IDs that have had their rendering settings reset.
        Throws:
        ValidationException -- if the image qualified by datasetId is not locatable.
        """
        def end_resetDefaultsInDataset(self, _r):
            return _M_omero.api.IRenderingSettings._op_resetDefaultsInDataset.end(self, _r)

        """
        Resets a rendering settings back to one or many containers
        that are specified by the rendering engine intelligent
        pretty good image (PG) logic. Supported container
        types are:
        omero.model.Project
        omero.model.Dataset
        omero.model.Image
        omero.model.Plate
        omero.model.Pixels
        Arguments:
        type -- The type of nodes to handle.
        nodeIds -- Ids of the node type.
        _ctx -- The request context for the invocation.
        Returns: A java.util.Set of image IDs that have had their rendering settings reset.
        Throws:
        ValidationException -- if an illegal type is used.
        """
        def resetDefaultsInSet(self, type, nodeIds, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_resetDefaultsInSet.invoke(self, ((type, nodeIds), _ctx))

        """
        Resets a rendering settings back to one or many containers
        that are specified by the rendering engine intelligent
        pretty good image (PG) logic. Supported container
        types are:
        omero.model.Project
        omero.model.Dataset
        omero.model.Image
        omero.model.Plate
        omero.model.Pixels
        Arguments:
        type -- The type of nodes to handle.
        nodeIds -- Ids of the node type.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_resetDefaultsInSet(self, type, nodeIds, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_resetDefaultsInSet.begin(self, ((type, nodeIds), _response, _ex, _sent, _ctx))

        """
        Resets a rendering settings back to one or many containers
        that are specified by the rendering engine intelligent
        pretty good image (PG) logic. Supported container
        types are:
        omero.model.Project
        omero.model.Dataset
        omero.model.Image
        omero.model.Plate
        omero.model.Pixels
        Arguments:
        type -- The type of nodes to handle.
        nodeIds -- Ids of the node type.
        Returns: A java.util.Set of image IDs that have had their rendering settings reset.
        Throws:
        ValidationException -- if an illegal type is used.
        """
        def end_resetDefaultsInSet(self, _r):
            return _M_omero.api.IRenderingSettings._op_resetDefaultsInSet.end(self, _r)

        """
        Resets the rendering settings of a given group of
        containers based on the owner's (essentially a copy).
        Supported container types are:
        omero.model.Project
        omero.model.Dataset
        omero.model.Image
        omero.model.Plate
        omero.model.Pixels
        Arguments:
        type -- The type of nodes to handle.
        nodeIds -- Ids of the node type.
        _ctx -- The request context for the invocation.
        Returns: A java.util.Set of image IDs that have had their rendering settings reset.
        Throws:
        ValidationException -- if an illegal type is used.
        """
        def resetDefaultsByOwnerInSet(self, type, nodeIds, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_resetDefaultsByOwnerInSet.invoke(self, ((type, nodeIds), _ctx))

        """
        Resets the rendering settings of a given group of
        containers based on the owner's (essentially a copy).
        Supported container types are:
        omero.model.Project
        omero.model.Dataset
        omero.model.Image
        omero.model.Plate
        omero.model.Pixels
        Arguments:
        type -- The type of nodes to handle.
        nodeIds -- Ids of the node type.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_resetDefaultsByOwnerInSet(self, type, nodeIds, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_resetDefaultsByOwnerInSet.begin(self, ((type, nodeIds), _response, _ex, _sent, _ctx))

        """
        Resets the rendering settings of a given group of
        containers based on the owner's (essentially a copy).
        Supported container types are:
        omero.model.Project
        omero.model.Dataset
        omero.model.Image
        omero.model.Plate
        omero.model.Pixels
        Arguments:
        type -- The type of nodes to handle.
        nodeIds -- Ids of the node type.
        Returns: A java.util.Set of image IDs that have had their rendering settings reset.
        Throws:
        ValidationException -- if an illegal type is used.
        """
        def end_resetDefaultsByOwnerInSet(self, _r):
            return _M_omero.api.IRenderingSettings._op_resetDefaultsByOwnerInSet.end(self, _r)

        """
        Resets a the channel windows for one or many containers
        back to their global minimum and global maximum for the
        channel. Supported container types are:
        omero.model.Project
        omero.model.Dataset
        omero.model.Image
        omero.model.Plate
        omero.model.Pixels
        Arguments:
        type -- The type of nodes to handle.
        nodeIds -- Ids of the node type.
        _ctx -- The request context for the invocation.
        Returns: A java.util.Set of image IDs that have had their rendering settings reset.
        Throws:
        ValidationException -- if an illegal type is used.
        """
        def resetMinMaxInSet(self, type, nodeIds, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_resetMinMaxInSet.invoke(self, ((type, nodeIds), _ctx))

        """
        Resets a the channel windows for one or many containers
        back to their global minimum and global maximum for the
        channel. Supported container types are:
        omero.model.Project
        omero.model.Dataset
        omero.model.Image
        omero.model.Plate
        omero.model.Pixels
        Arguments:
        type -- The type of nodes to handle.
        nodeIds -- Ids of the node type.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_resetMinMaxInSet(self, type, nodeIds, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_resetMinMaxInSet.begin(self, ((type, nodeIds), _response, _ex, _sent, _ctx))

        """
        Resets a the channel windows for one or many containers
        back to their global minimum and global maximum for the
        channel. Supported container types are:
        omero.model.Project
        omero.model.Dataset
        omero.model.Image
        omero.model.Plate
        omero.model.Pixels
        Arguments:
        type -- The type of nodes to handle.
        nodeIds -- Ids of the node type.
        Returns: A java.util.Set of image IDs that have had their rendering settings reset.
        Throws:
        ValidationException -- if an illegal type is used.
        """
        def end_resetMinMaxInSet(self, _r):
            return _M_omero.api.IRenderingSettings._op_resetMinMaxInSet.end(self, _r)

        """
        Applies rendering settings to one or many containers. If a
        container such as Dataset is to be copied to, all images
        within that Dataset will have the rendering settings
        applied. Supported container types are:
        omero.model.Project
        omero.model.Dataset
        omero.model.Image
        omero.model.Plate
        omero.model.Screen
        omero.model.Pixels
        Arguments:
        _from -- The Id of the pixels set to copy the rendering settings from.
        toType -- The type of nodes to handle.
        nodeIds -- Ids of the node type.
        _ctx -- The request context for the invocation.
        Returns: A map with two boolean keys. The value of the key TRUE is a collection of image IDs, the settings were successfully applied to. The value of the key FALSE is a collection of image IDs, the settings could not be applied to.
        Throws:
        ValidationException -- if an illegal type is used.
        """
        def applySettingsToSet(self, _from, toType, nodeIds, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_applySettingsToSet.invoke(self, ((_from, toType, nodeIds), _ctx))

        """
        Applies rendering settings to one or many containers. If a
        container such as Dataset is to be copied to, all images
        within that Dataset will have the rendering settings
        applied. Supported container types are:
        omero.model.Project
        omero.model.Dataset
        omero.model.Image
        omero.model.Plate
        omero.model.Screen
        omero.model.Pixels
        Arguments:
        _from -- The Id of the pixels set to copy the rendering settings from.
        toType -- The type of nodes to handle.
        nodeIds -- Ids of the node type.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_applySettingsToSet(self, _from, toType, nodeIds, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_applySettingsToSet.begin(self, ((_from, toType, nodeIds), _response, _ex, _sent, _ctx))

        """
        Applies rendering settings to one or many containers. If a
        container such as Dataset is to be copied to, all images
        within that Dataset will have the rendering settings
        applied. Supported container types are:
        omero.model.Project
        omero.model.Dataset
        omero.model.Image
        omero.model.Plate
        omero.model.Screen
        omero.model.Pixels
        Arguments:
        _from -- The Id of the pixels set to copy the rendering settings from.
        toType -- The type of nodes to handle.
        nodeIds -- Ids of the node type.
        Returns: A map with two boolean keys. The value of the key TRUE is a collection of image IDs, the settings were successfully applied to. The value of the key FALSE is a collection of image IDs, the settings could not be applied to.
        Throws:
        ValidationException -- if an illegal type is used.
        """
        def end_applySettingsToSet(self, _r):
            return _M_omero.api.IRenderingSettings._op_applySettingsToSet.end(self, _r)

        """
        Applies rendering settings to all images in all Datasets of
        a given Project.
        Arguments:
        _from -- The Id of the pixels set to copy the rendering settings from.
        to -- The Id of the project container to apply settings to.
        _ctx -- The request context for the invocation.
        Returns: A map with two boolean keys. The value of the TRUE is a collection of images ID, the settings were successfully applied to. The value of the FALSE is a collection of images ID, the settings could not be applied to.
        Throws:
        ValidationException -- if the rendering settings from is not locatable or the project to is not locatable.
        """
        def applySettingsToProject(self, _from, to, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_applySettingsToProject.invoke(self, ((_from, to), _ctx))

        """
        Applies rendering settings to all images in all Datasets of
        a given Project.
        Arguments:
        _from -- The Id of the pixels set to copy the rendering settings from.
        to -- The Id of the project container to apply settings to.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_applySettingsToProject(self, _from, to, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_applySettingsToProject.begin(self, ((_from, to), _response, _ex, _sent, _ctx))

        """
        Applies rendering settings to all images in all Datasets of
        a given Project.
        Arguments:
        _from -- The Id of the pixels set to copy the rendering settings from.
        to -- The Id of the project container to apply settings to.
        Returns: A map with two boolean keys. The value of the TRUE is a collection of images ID, the settings were successfully applied to. The value of the FALSE is a collection of images ID, the settings could not be applied to.
        Throws:
        ValidationException -- if the rendering settings from is not locatable or the project to is not locatable.
        """
        def end_applySettingsToProject(self, _r):
            return _M_omero.api.IRenderingSettings._op_applySettingsToProject.end(self, _r)

        """
        Applies rendering settings to all images in a given Dataset.
        Arguments:
        _from -- The Id of the pixels set to copy the rendering settings from.
        to -- The Id of the dataset container to apply settings to.
        _ctx -- The request context for the invocation.
        Returns: A map with two boolean keys. The value of the TRUE is a collection of images ID, the settings were successfully applied to. The value of the FALSE is a collection of images ID, the settings could not be applied to.
        Throws:
        ValidationException -- if the rendering settings from is not locatable or the dataset to is not locatable.
        """
        def applySettingsToDataset(self, _from, to, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_applySettingsToDataset.invoke(self, ((_from, to), _ctx))

        """
        Applies rendering settings to all images in a given Dataset.
        Arguments:
        _from -- The Id of the pixels set to copy the rendering settings from.
        to -- The Id of the dataset container to apply settings to.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_applySettingsToDataset(self, _from, to, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_applySettingsToDataset.begin(self, ((_from, to), _response, _ex, _sent, _ctx))

        """
        Applies rendering settings to all images in a given Dataset.
        Arguments:
        _from -- The Id of the pixels set to copy the rendering settings from.
        to -- The Id of the dataset container to apply settings to.
        Returns: A map with two boolean keys. The value of the TRUE is a collection of images ID, the settings were successfully applied to. The value of the FALSE is a collection of images ID, the settings could not be applied to.
        Throws:
        ValidationException -- if the rendering settings from is not locatable or the dataset to is not locatable.
        """
        def end_applySettingsToDataset(self, _r):
            return _M_omero.api.IRenderingSettings._op_applySettingsToDataset.end(self, _r)

        """
        Applies rendering settings to a given Image.
        Arguments:
        _from -- The Id of the pixels set to copy the rendering settings from.
        to -- The Id of the image container to apply settings to.
        _ctx -- The request context for the invocation.
        Returns: true if the settings were successfully applied, false otherwise.
        Throws:
        ValidationException -- if the rendering settings from is not locatable or the image to is not locatable.
        """
        def applySettingsToImages(self, _from, to, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_applySettingsToImages.invoke(self, ((_from, to), _ctx))

        """
        Applies rendering settings to a given Image.
        Arguments:
        _from -- The Id of the pixels set to copy the rendering settings from.
        to -- The Id of the image container to apply settings to.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_applySettingsToImages(self, _from, to, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_applySettingsToImages.begin(self, ((_from, to), _response, _ex, _sent, _ctx))

        """
        Applies rendering settings to a given Image.
        Arguments:
        _from -- The Id of the pixels set to copy the rendering settings from.
        to -- The Id of the image container to apply settings to.
        Returns: true if the settings were successfully applied, false otherwise.
        Throws:
        ValidationException -- if the rendering settings from is not locatable or the image to is not locatable.
        """
        def end_applySettingsToImages(self, _r):
            return _M_omero.api.IRenderingSettings._op_applySettingsToImages.end(self, _r)

        """
        Applies rendering settings to a given Image.
        Arguments:
        _from -- The Id of the pixels set to copy the rendering settings from.
        to -- The Id of the image container to apply settings to.
        _ctx -- The request context for the invocation.
        Returns: true if the settings were successfully applied, false otherwise.
        Throws:
        ValidationException -- if the rendering settings from is not locatable or the image to is not locatable.
        """
        def applySettingsToImage(self, _from, to, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_applySettingsToImage.invoke(self, ((_from, to), _ctx))

        """
        Applies rendering settings to a given Image.
        Arguments:
        _from -- The Id of the pixels set to copy the rendering settings from.
        to -- The Id of the image container to apply settings to.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_applySettingsToImage(self, _from, to, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_applySettingsToImage.begin(self, ((_from, to), _response, _ex, _sent, _ctx))

        """
        Applies rendering settings to a given Image.
        Arguments:
        _from -- The Id of the pixels set to copy the rendering settings from.
        to -- The Id of the image container to apply settings to.
        Returns: true if the settings were successfully applied, false otherwise.
        Throws:
        ValidationException -- if the rendering settings from is not locatable or the image to is not locatable.
        """
        def end_applySettingsToImage(self, _r):
            return _M_omero.api.IRenderingSettings._op_applySettingsToImage.end(self, _r)

        """
        Applies rendering settings to a given Pixels.
        Arguments:
        _from -- The Id of the pixels set to copy the rendering settings from.
        to -- The Id of the pixels container to apply settings to.
        _ctx -- The request context for the invocation.
        Returns: See above.
        Throws:
        ValidationException -- if the rendering settings from is not locatable or the pixelsto is not locatable.
        """
        def applySettingsToPixels(self, _from, to, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_applySettingsToPixels.invoke(self, ((_from, to), _ctx))

        """
        Applies rendering settings to a given Pixels.
        Arguments:
        _from -- The Id of the pixels set to copy the rendering settings from.
        to -- The Id of the pixels container to apply settings to.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_applySettingsToPixels(self, _from, to, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_applySettingsToPixels.begin(self, ((_from, to), _response, _ex, _sent, _ctx))

        """
        Applies rendering settings to a given Pixels.
        Arguments:
        _from -- The Id of the pixels set to copy the rendering settings from.
        to -- The Id of the pixels container to apply settings to.
        Returns: See above.
        Throws:
        ValidationException -- if the rendering settings from is not locatable or the pixelsto is not locatable.
        """
        def end_applySettingsToPixels(self, _r):
            return _M_omero.api.IRenderingSettings._op_applySettingsToPixels.end(self, _r)

        """
        Resets an image's default rendering settings back to
        channel global minimum and maximum.
        Arguments:
        imageId -- The Id of the Image.
        _ctx -- The request context for the invocation.
        Throws:
        ValidationException -- if the image qualified by imageId is not locatable.
        """
        def setOriginalSettingsInImage(self, imageId, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_setOriginalSettingsInImage.invoke(self, ((imageId, ), _ctx))

        """
        Resets an image's default rendering settings back to
        channel global minimum and maximum.
        Arguments:
        imageId -- The Id of the Image.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_setOriginalSettingsInImage(self, imageId, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_setOriginalSettingsInImage.begin(self, ((imageId, ), _response, _ex, _sent, _ctx))

        """
        Resets an image's default rendering settings back to
        channel global minimum and maximum.
        Arguments:
        imageId -- The Id of the Image.
        Throws:
        ValidationException -- if the image qualified by imageId is not locatable.
        """
        def end_setOriginalSettingsInImage(self, _r):
            return _M_omero.api.IRenderingSettings._op_setOriginalSettingsInImage.end(self, _r)

        """
        Resets an Pixels' default rendering settings back to
        channel global minimum and maximum.
        Arguments:
        pixelsId -- The Id of the Pixels set.
        _ctx -- The request context for the invocation.
        Throws:
        ValidationException -- if the image qualified by pixelsId is not locatable.
        """
        def setOriginalSettingsForPixels(self, pixelsId, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_setOriginalSettingsForPixels.invoke(self, ((pixelsId, ), _ctx))

        """
        Resets an Pixels' default rendering settings back to
        channel global minimum and maximum.
        Arguments:
        pixelsId -- The Id of the Pixels set.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_setOriginalSettingsForPixels(self, pixelsId, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_setOriginalSettingsForPixels.begin(self, ((pixelsId, ), _response, _ex, _sent, _ctx))

        """
        Resets an Pixels' default rendering settings back to
        channel global minimum and maximum.
        Arguments:
        pixelsId -- The Id of the Pixels set.
        Throws:
        ValidationException -- if the image qualified by pixelsId is not locatable.
        """
        def end_setOriginalSettingsForPixels(self, _r):
            return _M_omero.api.IRenderingSettings._op_setOriginalSettingsForPixels.end(self, _r)

        """
        Resets a dataset's rendering settings back to channel global
        minimum and maximum.
        Arguments:
        datasetId -- The id of the dataset to handle.
        _ctx -- The request context for the invocation.
        Returns: A java.util.Set of image IDs that have had their rendering settings reset.
        Throws:
        ValidationException -- if the image qualified by datasetId is not locatable.
        """
        def setOriginalSettingsInDataset(self, datasetId, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_setOriginalSettingsInDataset.invoke(self, ((datasetId, ), _ctx))

        """
        Resets a dataset's rendering settings back to channel global
        minimum and maximum.
        Arguments:
        datasetId -- The id of the dataset to handle.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_setOriginalSettingsInDataset(self, datasetId, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_setOriginalSettingsInDataset.begin(self, ((datasetId, ), _response, _ex, _sent, _ctx))

        """
        Resets a dataset's rendering settings back to channel global
        minimum and maximum.
        Arguments:
        datasetId -- The id of the dataset to handle.
        Returns: A java.util.Set of image IDs that have had their rendering settings reset.
        Throws:
        ValidationException -- if the image qualified by datasetId is not locatable.
        """
        def end_setOriginalSettingsInDataset(self, _r):
            return _M_omero.api.IRenderingSettings._op_setOriginalSettingsInDataset.end(self, _r)

        """
        Resets a rendering settings back to channel global minimum
        and maximum for the specified containers. Supported
        container types are:
        omero.model.Project
        omero.model.Dataset
        omero.model.Image
        omero.model.Plate
        omero.model.Pixels
        Arguments:
        type -- The type of nodes to handle.
        nodeIds -- Ids of the node type.
        _ctx -- The request context for the invocation.
        Returns: A java.util.Set of image IDs that have had their rendering settings reset.
        Throws:
        ValidationException -- if an illegal type is used.
        """
        def setOriginalSettingsInSet(self, type, nodeIds, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_setOriginalSettingsInSet.invoke(self, ((type, nodeIds), _ctx))

        """
        Resets a rendering settings back to channel global minimum
        and maximum for the specified containers. Supported
        container types are:
        omero.model.Project
        omero.model.Dataset
        omero.model.Image
        omero.model.Plate
        omero.model.Pixels
        Arguments:
        type -- The type of nodes to handle.
        nodeIds -- Ids of the node type.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_setOriginalSettingsInSet(self, type, nodeIds, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IRenderingSettings._op_setOriginalSettingsInSet.begin(self, ((type, nodeIds), _response, _ex, _sent, _ctx))

        """
        Resets a rendering settings back to channel global minimum
        and maximum for the specified containers. Supported
        container types are:
        omero.model.Project
        omero.model.Dataset
        omero.model.Image
        omero.model.Plate
        omero.model.Pixels
        Arguments:
        type -- The type of nodes to handle.
        nodeIds -- Ids of the node type.
        Returns: A java.util.Set of image IDs that have had their rendering settings reset.
        Throws:
        ValidationException -- if an illegal type is used.
        """
        def end_setOriginalSettingsInSet(self, _r):
            return _M_omero.api.IRenderingSettings._op_setOriginalSettingsInSet.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.api.IRenderingSettingsPrx.ice_checkedCast(proxy, '::omero::api::IRenderingSettings', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.api.IRenderingSettingsPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::api::IRenderingSettings'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.api._t_IRenderingSettingsPrx = IcePy.defineProxy('::omero::api::IRenderingSettings', IRenderingSettingsPrx)

    _M_omero.api._t_IRenderingSettings = IcePy.defineClass('::omero::api::IRenderingSettings', IRenderingSettings, -1, (), True, False, None, (_M_omero.api._t_ServiceInterface,), ())
    IRenderingSettings._ice_type = _M_omero.api._t_IRenderingSettings

    IRenderingSettings._op_sanityCheckPixels = IcePy.Operation('sanityCheckPixels', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), _M_omero.model._t_Pixels, False, 0), ((), _M_omero.model._t_Pixels, False, 0)), (), ((), IcePy._t_bool, False, 0), (_M_omero._t_ServerError,))
    IRenderingSettings._op_getRenderingSettings = IcePy.Operation('getRenderingSettings', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_long, False, 0),), (), ((), _M_omero.model._t_RenderingDef, False, 0), (_M_omero._t_ServerError,))
    IRenderingSettings._op_createNewRenderingDef = IcePy.Operation('createNewRenderingDef', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), _M_omero.model._t_Pixels, False, 0),), (), ((), _M_omero.model._t_RenderingDef, False, 0), (_M_omero._t_ServerError,))
    IRenderingSettings._op_resetDefaults = IcePy.Operation('resetDefaults', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), _M_omero.model._t_RenderingDef, False, 0), ((), _M_omero.model._t_Pixels, False, 0)), (), None, (_M_omero._t_ServerError,))
    IRenderingSettings._op_resetDefaultsNoSave = IcePy.Operation('resetDefaultsNoSave', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), _M_omero.model._t_RenderingDef, False, 0), ((), _M_omero.model._t_Pixels, False, 0)), (), ((), _M_omero.model._t_RenderingDef, False, 0), (_M_omero._t_ServerError,))
    IRenderingSettings._op_resetDefaultsInImage = IcePy.Operation('resetDefaultsInImage', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_long, False, 0),), (), None, (_M_omero._t_ServerError,))
    IRenderingSettings._op_resetDefaultsForPixels = IcePy.Operation('resetDefaultsForPixels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_long, False, 0),), (), None, (_M_omero._t_ServerError,))
    IRenderingSettings._op_resetDefaultsInDataset = IcePy.Operation('resetDefaultsInDataset', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_long, False, 0),), (), ((), _M_omero.sys._t_LongList, False, 0), (_M_omero._t_ServerError,))
    IRenderingSettings._op_resetDefaultsInSet = IcePy.Operation('resetDefaultsInSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_string, False, 0), ((), _M_omero.sys._t_LongList, False, 0)), (), ((), _M_omero.sys._t_LongList, False, 0), (_M_omero._t_ServerError,))
    IRenderingSettings._op_resetDefaultsByOwnerInSet = IcePy.Operation('resetDefaultsByOwnerInSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_string, False, 0), ((), _M_omero.sys._t_LongList, False, 0)), (), ((), _M_omero.sys._t_LongList, False, 0), (_M_omero._t_ServerError,))
    IRenderingSettings._op_resetMinMaxInSet = IcePy.Operation('resetMinMaxInSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_string, False, 0), ((), _M_omero.sys._t_LongList, False, 0)), (), ((), _M_omero.sys._t_LongList, False, 0), (_M_omero._t_ServerError,))
    IRenderingSettings._op_applySettingsToSet = IcePy.Operation('applySettingsToSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_long, False, 0), ((), IcePy._t_string, False, 0), ((), _M_omero.sys._t_LongList, False, 0)), (), ((), _M_omero.api._t_BooleanIdListMap, False, 0), (_M_omero._t_ServerError,))
    IRenderingSettings._op_applySettingsToProject = IcePy.Operation('applySettingsToProject', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_long, False, 0), ((), IcePy._t_long, False, 0)), (), ((), _M_omero.api._t_BooleanIdListMap, False, 0), (_M_omero._t_ServerError,))
    IRenderingSettings._op_applySettingsToDataset = IcePy.Operation('applySettingsToDataset', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_long, False, 0), ((), IcePy._t_long, False, 0)), (), ((), _M_omero.api._t_BooleanIdListMap, False, 0), (_M_omero._t_ServerError,))
    IRenderingSettings._op_applySettingsToImages = IcePy.Operation('applySettingsToImages', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_long, False, 0), ((), _M_omero.sys._t_LongList, False, 0)), (), ((), _M_omero.api._t_BooleanIdListMap, False, 0), (_M_omero._t_ServerError,))
    IRenderingSettings._op_applySettingsToImage = IcePy.Operation('applySettingsToImage', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_long, False, 0), ((), IcePy._t_long, False, 0)), (), ((), IcePy._t_bool, False, 0), (_M_omero._t_ServerError,))
    IRenderingSettings._op_applySettingsToPixels = IcePy.Operation('applySettingsToPixels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_long, False, 0), ((), IcePy._t_long, False, 0)), (), ((), IcePy._t_bool, False, 0), (_M_omero._t_ServerError,))
    IRenderingSettings._op_setOriginalSettingsInImage = IcePy.Operation('setOriginalSettingsInImage', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_long, False, 0),), (), None, (_M_omero._t_ServerError,))
    IRenderingSettings._op_setOriginalSettingsForPixels = IcePy.Operation('setOriginalSettingsForPixels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_long, False, 0),), (), None, (_M_omero._t_ServerError,))
    IRenderingSettings._op_setOriginalSettingsInDataset = IcePy.Operation('setOriginalSettingsInDataset', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_long, False, 0),), (), ((), _M_omero.sys._t_LongList, False, 0), (_M_omero._t_ServerError,))
    IRenderingSettings._op_setOriginalSettingsInSet = IcePy.Operation('setOriginalSettingsInSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_string, False, 0), ((), _M_omero.sys._t_LongList, False, 0)), (), ((), _M_omero.sys._t_LongList, False, 0), (_M_omero._t_ServerError,))

    _M_omero.api.IRenderingSettings = IRenderingSettings
    del IRenderingSettings

    _M_omero.api.IRenderingSettingsPrx = IRenderingSettingsPrx
    del IRenderingSettingsPrx

# End of module omero.api

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Screen.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'ScreenPlateLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_ScreenPlateLink = IcePy.declareClass('::omero::model::ScreenPlateLink')
    _M_omero.model._t_ScreenPlateLinkPrx = IcePy.declareProxy('::omero::model::ScreenPlateLink')

if 'Plate' not in _M_omero.model.__dict__:
    _M_omero.model._t_Plate = IcePy.declareClass('::omero::model::Plate')
    _M_omero.model._t_PlatePrx = IcePy.declareProxy('::omero::model::Plate')

if 'Reagent' not in _M_omero.model.__dict__:
    _M_omero.model._t_Reagent = IcePy.declareClass('::omero::model::Reagent')
    _M_omero.model._t_ReagentPrx = IcePy.declareProxy('::omero::model::Reagent')

if 'ScreenAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_ScreenAnnotationLink = IcePy.declareClass('::omero::model::ScreenAnnotationLink')
    _M_omero.model._t_ScreenAnnotationLinkPrx = IcePy.declareProxy('::omero::model::ScreenAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_ScreenPlateLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ScreenPlateLinksSeq = IcePy.defineSequence('::omero::model::ScreenPlateLinksSeq', (), _M_omero.model._t_ScreenPlateLink)

if '_t_ScreenLinkedPlateSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ScreenLinkedPlateSeq = IcePy.defineSequence('::omero::model::ScreenLinkedPlateSeq', (), _M_omero.model._t_Plate)

if '_t_ScreenReagentsSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ScreenReagentsSeq = IcePy.defineSequence('::omero::model::ScreenReagentsSeq', (), _M_omero.model._t_Reagent)

if '_t_ScreenAnnotationLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ScreenAnnotationLinksSeq = IcePy.defineSequence('::omero::model::ScreenAnnotationLinksSeq', (), _M_omero.model._t_ScreenAnnotationLink)

if '_t_ScreenLinkedAnnotationSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ScreenLinkedAnnotationSeq = IcePy.defineSequence('::omero::model::ScreenLinkedAnnotationSeq', (), _M_omero.model._t_Annotation)

if 'Screen' not in _M_omero.model.__dict__:
    _M_omero.model.Screen = Ice.createTempClass()
    class Screen(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _type=None, _protocolIdentifier=None, _protocolDescription=None, _reagentSetIdentifier=None, _reagentSetDescription=None, _plateLinksSeq=None, _plateLinksLoaded=False, _plateLinksCountPerOwner=None, _reagentsSeq=None, _reagentsLoaded=False, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None, _name=None, _description=None):
            if Ice.getType(self) == _M_omero.model.Screen:
                raise RuntimeError('omero.model.Screen is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._type = _type
            self._protocolIdentifier = _protocolIdentifier
            self._protocolDescription = _protocolDescription
            self._reagentSetIdentifier = _reagentSetIdentifier
            self._reagentSetDescription = _reagentSetDescription
            self._plateLinksSeq = _plateLinksSeq
            self._plateLinksLoaded = _plateLinksLoaded
            self._plateLinksCountPerOwner = _plateLinksCountPerOwner
            self._reagentsSeq = _reagentsSeq
            self._reagentsLoaded = _reagentsLoaded
            self._annotationLinksSeq = _annotationLinksSeq
            self._annotationLinksLoaded = _annotationLinksLoaded
            self._annotationLinksCountPerOwner = _annotationLinksCountPerOwner
            self._name = _name
            self._description = _description

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::Screen')

        def ice_id(self, current=None):
            return '::omero::model::Screen'

        def ice_staticId():
            return '::omero::model::Screen'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getType(self, current=None):
            pass

        def setType(self, theType, current=None):
            pass

        def getProtocolIdentifier(self, current=None):
            pass

        def setProtocolIdentifier(self, theProtocolIdentifier, current=None):
            pass

        def getProtocolDescription(self, current=None):
            pass

        def setProtocolDescription(self, theProtocolDescription, current=None):
            pass

        def getReagentSetIdentifier(self, current=None):
            pass

        def setReagentSetIdentifier(self, theReagentSetIdentifier, current=None):
            pass

        def getReagentSetDescription(self, current=None):
            pass

        def setReagentSetDescription(self, theReagentSetDescription, current=None):
            pass

        def unloadPlateLinks(self, current=None):
            pass

        def sizeOfPlateLinks(self, current=None):
            pass

        def copyPlateLinks(self, current=None):
            pass

        def addScreenPlateLink(self, target, current=None):
            pass

        def addAllScreenPlateLinkSet(self, targets, current=None):
            pass

        def removeScreenPlateLink(self, theTarget, current=None):
            pass

        def removeAllScreenPlateLinkSet(self, targets, current=None):
            pass

        def clearPlateLinks(self, current=None):
            pass

        def reloadPlateLinks(self, toCopy, current=None):
            pass

        def getPlateLinksCountPerOwner(self, current=None):
            pass

        def linkPlate(self, addition, current=None):
            pass

        def addScreenPlateLinkToBoth(self, link, bothSides, current=None):
            pass

        def findScreenPlateLink(self, removal, current=None):
            pass

        def unlinkPlate(self, removal, current=None):
            pass

        def removeScreenPlateLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedPlateList(self, current=None):
            pass

        def unloadReagents(self, current=None):
            pass

        def sizeOfReagents(self, current=None):
            pass

        def copyReagents(self, current=None):
            pass

        def addReagent(self, target, current=None):
            pass

        def addAllReagentSet(self, targets, current=None):
            pass

        def removeReagent(self, theTarget, current=None):
            pass

        def removeAllReagentSet(self, targets, current=None):
            pass

        def clearReagents(self, current=None):
            pass

        def reloadReagents(self, toCopy, current=None):
            pass

        def unloadAnnotationLinks(self, current=None):
            pass

        def sizeOfAnnotationLinks(self, current=None):
            pass

        def copyAnnotationLinks(self, current=None):
            pass

        def addScreenAnnotationLink(self, target, current=None):
            pass

        def addAllScreenAnnotationLinkSet(self, targets, current=None):
            pass

        def removeScreenAnnotationLink(self, theTarget, current=None):
            pass

        def removeAllScreenAnnotationLinkSet(self, targets, current=None):
            pass

        def clearAnnotationLinks(self, current=None):
            pass

        def reloadAnnotationLinks(self, toCopy, current=None):
            pass

        def getAnnotationLinksCountPerOwner(self, current=None):
            pass

        def linkAnnotation(self, addition, current=None):
            pass

        def addScreenAnnotationLinkToBoth(self, link, bothSides, current=None):
            pass

        def findScreenAnnotationLink(self, removal, current=None):
            pass

        def unlinkAnnotation(self, removal, current=None):
            pass

        def removeScreenAnnotationLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedAnnotationList(self, current=None):
            pass

        def getName(self, current=None):
            pass

        def setName(self, theName, current=None):
            pass

        def getDescription(self, current=None):
            pass

        def setDescription(self, theDescription, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_Screen)

        __repr__ = __str__

    _M_omero.model.ScreenPrx = Ice.createTempClass()
    class ScreenPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.Screen._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.Screen._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.Screen._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.Screen._op_setVersion.end(self, _r)

        def getType(self, _ctx=None):
            return _M_omero.model.Screen._op_getType.invoke(self, ((), _ctx))

        def begin_getType(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_getType.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getType(self, _r):
            return _M_omero.model.Screen._op_getType.end(self, _r)

        def setType(self, theType, _ctx=None):
            return _M_omero.model.Screen._op_setType.invoke(self, ((theType, ), _ctx))

        def begin_setType(self, theType, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_setType.begin(self, ((theType, ), _response, _ex, _sent, _ctx))

        def end_setType(self, _r):
            return _M_omero.model.Screen._op_setType.end(self, _r)

        def getProtocolIdentifier(self, _ctx=None):
            return _M_omero.model.Screen._op_getProtocolIdentifier.invoke(self, ((), _ctx))

        def begin_getProtocolIdentifier(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_getProtocolIdentifier.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getProtocolIdentifier(self, _r):
            return _M_omero.model.Screen._op_getProtocolIdentifier.end(self, _r)

        def setProtocolIdentifier(self, theProtocolIdentifier, _ctx=None):
            return _M_omero.model.Screen._op_setProtocolIdentifier.invoke(self, ((theProtocolIdentifier, ), _ctx))

        def begin_setProtocolIdentifier(self, theProtocolIdentifier, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_setProtocolIdentifier.begin(self, ((theProtocolIdentifier, ), _response, _ex, _sent, _ctx))

        def end_setProtocolIdentifier(self, _r):
            return _M_omero.model.Screen._op_setProtocolIdentifier.end(self, _r)

        def getProtocolDescription(self, _ctx=None):
            return _M_omero.model.Screen._op_getProtocolDescription.invoke(self, ((), _ctx))

        def begin_getProtocolDescription(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_getProtocolDescription.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getProtocolDescription(self, _r):
            return _M_omero.model.Screen._op_getProtocolDescription.end(self, _r)

        def setProtocolDescription(self, theProtocolDescription, _ctx=None):
            return _M_omero.model.Screen._op_setProtocolDescription.invoke(self, ((theProtocolDescription, ), _ctx))

        def begin_setProtocolDescription(self, theProtocolDescription, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_setProtocolDescription.begin(self, ((theProtocolDescription, ), _response, _ex, _sent, _ctx))

        def end_setProtocolDescription(self, _r):
            return _M_omero.model.Screen._op_setProtocolDescription.end(self, _r)

        def getReagentSetIdentifier(self, _ctx=None):
            return _M_omero.model.Screen._op_getReagentSetIdentifier.invoke(self, ((), _ctx))

        def begin_getReagentSetIdentifier(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_getReagentSetIdentifier.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getReagentSetIdentifier(self, _r):
            return _M_omero.model.Screen._op_getReagentSetIdentifier.end(self, _r)

        def setReagentSetIdentifier(self, theReagentSetIdentifier, _ctx=None):
            return _M_omero.model.Screen._op_setReagentSetIdentifier.invoke(self, ((theReagentSetIdentifier, ), _ctx))

        def begin_setReagentSetIdentifier(self, theReagentSetIdentifier, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_setReagentSetIdentifier.begin(self, ((theReagentSetIdentifier, ), _response, _ex, _sent, _ctx))

        def end_setReagentSetIdentifier(self, _r):
            return _M_omero.model.Screen._op_setReagentSetIdentifier.end(self, _r)

        def getReagentSetDescription(self, _ctx=None):
            return _M_omero.model.Screen._op_getReagentSetDescription.invoke(self, ((), _ctx))

        def begin_getReagentSetDescription(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_getReagentSetDescription.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getReagentSetDescription(self, _r):
            return _M_omero.model.Screen._op_getReagentSetDescription.end(self, _r)

        def setReagentSetDescription(self, theReagentSetDescription, _ctx=None):
            return _M_omero.model.Screen._op_setReagentSetDescription.invoke(self, ((theReagentSetDescription, ), _ctx))

        def begin_setReagentSetDescription(self, theReagentSetDescription, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_setReagentSetDescription.begin(self, ((theReagentSetDescription, ), _response, _ex, _sent, _ctx))

        def end_setReagentSetDescription(self, _r):
            return _M_omero.model.Screen._op_setReagentSetDescription.end(self, _r)

        def unloadPlateLinks(self, _ctx=None):
            return _M_omero.model.Screen._op_unloadPlateLinks.invoke(self, ((), _ctx))

        def begin_unloadPlateLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_unloadPlateLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadPlateLinks(self, _r):
            return _M_omero.model.Screen._op_unloadPlateLinks.end(self, _r)

        def sizeOfPlateLinks(self, _ctx=None):
            return _M_omero.model.Screen._op_sizeOfPlateLinks.invoke(self, ((), _ctx))

        def begin_sizeOfPlateLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_sizeOfPlateLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfPlateLinks(self, _r):
            return _M_omero.model.Screen._op_sizeOfPlateLinks.end(self, _r)

        def copyPlateLinks(self, _ctx=None):
            return _M_omero.model.Screen._op_copyPlateLinks.invoke(self, ((), _ctx))

        def begin_copyPlateLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_copyPlateLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyPlateLinks(self, _r):
            return _M_omero.model.Screen._op_copyPlateLinks.end(self, _r)

        def addScreenPlateLink(self, target, _ctx=None):
            return _M_omero.model.Screen._op_addScreenPlateLink.invoke(self, ((target, ), _ctx))

        def begin_addScreenPlateLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_addScreenPlateLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addScreenPlateLink(self, _r):
            return _M_omero.model.Screen._op_addScreenPlateLink.end(self, _r)

        def addAllScreenPlateLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Screen._op_addAllScreenPlateLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllScreenPlateLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_addAllScreenPlateLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllScreenPlateLinkSet(self, _r):
            return _M_omero.model.Screen._op_addAllScreenPlateLinkSet.end(self, _r)

        def removeScreenPlateLink(self, theTarget, _ctx=None):
            return _M_omero.model.Screen._op_removeScreenPlateLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeScreenPlateLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_removeScreenPlateLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeScreenPlateLink(self, _r):
            return _M_omero.model.Screen._op_removeScreenPlateLink.end(self, _r)

        def removeAllScreenPlateLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Screen._op_removeAllScreenPlateLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllScreenPlateLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_removeAllScreenPlateLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllScreenPlateLinkSet(self, _r):
            return _M_omero.model.Screen._op_removeAllScreenPlateLinkSet.end(self, _r)

        def clearPlateLinks(self, _ctx=None):
            return _M_omero.model.Screen._op_clearPlateLinks.invoke(self, ((), _ctx))

        def begin_clearPlateLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_clearPlateLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearPlateLinks(self, _r):
            return _M_omero.model.Screen._op_clearPlateLinks.end(self, _r)

        def reloadPlateLinks(self, toCopy, _ctx=None):
            return _M_omero.model.Screen._op_reloadPlateLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadPlateLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_reloadPlateLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadPlateLinks(self, _r):
            return _M_omero.model.Screen._op_reloadPlateLinks.end(self, _r)

        def getPlateLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.Screen._op_getPlateLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getPlateLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_getPlateLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPlateLinksCountPerOwner(self, _r):
            return _M_omero.model.Screen._op_getPlateLinksCountPerOwner.end(self, _r)

        def linkPlate(self, addition, _ctx=None):
            return _M_omero.model.Screen._op_linkPlate.invoke(self, ((addition, ), _ctx))

        def begin_linkPlate(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_linkPlate.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkPlate(self, _r):
            return _M_omero.model.Screen._op_linkPlate.end(self, _r)

        def addScreenPlateLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Screen._op_addScreenPlateLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addScreenPlateLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_addScreenPlateLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addScreenPlateLinkToBoth(self, _r):
            return _M_omero.model.Screen._op_addScreenPlateLinkToBoth.end(self, _r)

        def findScreenPlateLink(self, removal, _ctx=None):
            return _M_omero.model.Screen._op_findScreenPlateLink.invoke(self, ((removal, ), _ctx))

        def begin_findScreenPlateLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_findScreenPlateLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findScreenPlateLink(self, _r):
            return _M_omero.model.Screen._op_findScreenPlateLink.end(self, _r)

        def unlinkPlate(self, removal, _ctx=None):
            return _M_omero.model.Screen._op_unlinkPlate.invoke(self, ((removal, ), _ctx))

        def begin_unlinkPlate(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_unlinkPlate.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkPlate(self, _r):
            return _M_omero.model.Screen._op_unlinkPlate.end(self, _r)

        def removeScreenPlateLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Screen._op_removeScreenPlateLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeScreenPlateLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_removeScreenPlateLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeScreenPlateLinkFromBoth(self, _r):
            return _M_omero.model.Screen._op_removeScreenPlateLinkFromBoth.end(self, _r)

        def linkedPlateList(self, _ctx=None):
            return _M_omero.model.Screen._op_linkedPlateList.invoke(self, ((), _ctx))

        def begin_linkedPlateList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_linkedPlateList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedPlateList(self, _r):
            return _M_omero.model.Screen._op_linkedPlateList.end(self, _r)

        def unloadReagents(self, _ctx=None):
            return _M_omero.model.Screen._op_unloadReagents.invoke(self, ((), _ctx))

        def begin_unloadReagents(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_unloadReagents.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadReagents(self, _r):
            return _M_omero.model.Screen._op_unloadReagents.end(self, _r)

        def sizeOfReagents(self, _ctx=None):
            return _M_omero.model.Screen._op_sizeOfReagents.invoke(self, ((), _ctx))

        def begin_sizeOfReagents(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_sizeOfReagents.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfReagents(self, _r):
            return _M_omero.model.Screen._op_sizeOfReagents.end(self, _r)

        def copyReagents(self, _ctx=None):
            return _M_omero.model.Screen._op_copyReagents.invoke(self, ((), _ctx))

        def begin_copyReagents(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_copyReagents.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyReagents(self, _r):
            return _M_omero.model.Screen._op_copyReagents.end(self, _r)

        def addReagent(self, target, _ctx=None):
            return _M_omero.model.Screen._op_addReagent.invoke(self, ((target, ), _ctx))

        def begin_addReagent(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_addReagent.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addReagent(self, _r):
            return _M_omero.model.Screen._op_addReagent.end(self, _r)

        def addAllReagentSet(self, targets, _ctx=None):
            return _M_omero.model.Screen._op_addAllReagentSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllReagentSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_addAllReagentSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllReagentSet(self, _r):
            return _M_omero.model.Screen._op_addAllReagentSet.end(self, _r)

        def removeReagent(self, theTarget, _ctx=None):
            return _M_omero.model.Screen._op_removeReagent.invoke(self, ((theTarget, ), _ctx))

        def begin_removeReagent(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_removeReagent.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeReagent(self, _r):
            return _M_omero.model.Screen._op_removeReagent.end(self, _r)

        def removeAllReagentSet(self, targets, _ctx=None):
            return _M_omero.model.Screen._op_removeAllReagentSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllReagentSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_removeAllReagentSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllReagentSet(self, _r):
            return _M_omero.model.Screen._op_removeAllReagentSet.end(self, _r)

        def clearReagents(self, _ctx=None):
            return _M_omero.model.Screen._op_clearReagents.invoke(self, ((), _ctx))

        def begin_clearReagents(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_clearReagents.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearReagents(self, _r):
            return _M_omero.model.Screen._op_clearReagents.end(self, _r)

        def reloadReagents(self, toCopy, _ctx=None):
            return _M_omero.model.Screen._op_reloadReagents.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadReagents(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_reloadReagents.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadReagents(self, _r):
            return _M_omero.model.Screen._op_reloadReagents.end(self, _r)

        def unloadAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Screen._op_unloadAnnotationLinks.invoke(self, ((), _ctx))

        def begin_unloadAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_unloadAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadAnnotationLinks(self, _r):
            return _M_omero.model.Screen._op_unloadAnnotationLinks.end(self, _r)

        def sizeOfAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Screen._op_sizeOfAnnotationLinks.invoke(self, ((), _ctx))

        def begin_sizeOfAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_sizeOfAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfAnnotationLinks(self, _r):
            return _M_omero.model.Screen._op_sizeOfAnnotationLinks.end(self, _r)

        def copyAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Screen._op_copyAnnotationLinks.invoke(self, ((), _ctx))

        def begin_copyAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_copyAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyAnnotationLinks(self, _r):
            return _M_omero.model.Screen._op_copyAnnotationLinks.end(self, _r)

        def addScreenAnnotationLink(self, target, _ctx=None):
            return _M_omero.model.Screen._op_addScreenAnnotationLink.invoke(self, ((target, ), _ctx))

        def begin_addScreenAnnotationLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_addScreenAnnotationLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addScreenAnnotationLink(self, _r):
            return _M_omero.model.Screen._op_addScreenAnnotationLink.end(self, _r)

        def addAllScreenAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Screen._op_addAllScreenAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllScreenAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_addAllScreenAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllScreenAnnotationLinkSet(self, _r):
            return _M_omero.model.Screen._op_addAllScreenAnnotationLinkSet.end(self, _r)

        def removeScreenAnnotationLink(self, theTarget, _ctx=None):
            return _M_omero.model.Screen._op_removeScreenAnnotationLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeScreenAnnotationLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_removeScreenAnnotationLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeScreenAnnotationLink(self, _r):
            return _M_omero.model.Screen._op_removeScreenAnnotationLink.end(self, _r)

        def removeAllScreenAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Screen._op_removeAllScreenAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllScreenAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_removeAllScreenAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllScreenAnnotationLinkSet(self, _r):
            return _M_omero.model.Screen._op_removeAllScreenAnnotationLinkSet.end(self, _r)

        def clearAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Screen._op_clearAnnotationLinks.invoke(self, ((), _ctx))

        def begin_clearAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_clearAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearAnnotationLinks(self, _r):
            return _M_omero.model.Screen._op_clearAnnotationLinks.end(self, _r)

        def reloadAnnotationLinks(self, toCopy, _ctx=None):
            return _M_omero.model.Screen._op_reloadAnnotationLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadAnnotationLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_reloadAnnotationLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadAnnotationLinks(self, _r):
            return _M_omero.model.Screen._op_reloadAnnotationLinks.end(self, _r)

        def getAnnotationLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.Screen._op_getAnnotationLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getAnnotationLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_getAnnotationLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAnnotationLinksCountPerOwner(self, _r):
            return _M_omero.model.Screen._op_getAnnotationLinksCountPerOwner.end(self, _r)

        def linkAnnotation(self, addition, _ctx=None):
            return _M_omero.model.Screen._op_linkAnnotation.invoke(self, ((addition, ), _ctx))

        def begin_linkAnnotation(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_linkAnnotation.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkAnnotation(self, _r):
            return _M_omero.model.Screen._op_linkAnnotation.end(self, _r)

        def addScreenAnnotationLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Screen._op_addScreenAnnotationLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addScreenAnnotationLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_addScreenAnnotationLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addScreenAnnotationLinkToBoth(self, _r):
            return _M_omero.model.Screen._op_addScreenAnnotationLinkToBoth.end(self, _r)

        def findScreenAnnotationLink(self, removal, _ctx=None):
            return _M_omero.model.Screen._op_findScreenAnnotationLink.invoke(self, ((removal, ), _ctx))

        def begin_findScreenAnnotationLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_findScreenAnnotationLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findScreenAnnotationLink(self, _r):
            return _M_omero.model.Screen._op_findScreenAnnotationLink.end(self, _r)

        def unlinkAnnotation(self, removal, _ctx=None):
            return _M_omero.model.Screen._op_unlinkAnnotation.invoke(self, ((removal, ), _ctx))

        def begin_unlinkAnnotation(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_unlinkAnnotation.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkAnnotation(self, _r):
            return _M_omero.model.Screen._op_unlinkAnnotation.end(self, _r)

        def removeScreenAnnotationLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Screen._op_removeScreenAnnotationLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeScreenAnnotationLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_removeScreenAnnotationLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeScreenAnnotationLinkFromBoth(self, _r):
            return _M_omero.model.Screen._op_removeScreenAnnotationLinkFromBoth.end(self, _r)

        def linkedAnnotationList(self, _ctx=None):
            return _M_omero.model.Screen._op_linkedAnnotationList.invoke(self, ((), _ctx))

        def begin_linkedAnnotationList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_linkedAnnotationList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedAnnotationList(self, _r):
            return _M_omero.model.Screen._op_linkedAnnotationList.end(self, _r)

        def getName(self, _ctx=None):
            return _M_omero.model.Screen._op_getName.invoke(self, ((), _ctx))

        def begin_getName(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_getName.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getName(self, _r):
            return _M_omero.model.Screen._op_getName.end(self, _r)

        def setName(self, theName, _ctx=None):
            return _M_omero.model.Screen._op_setName.invoke(self, ((theName, ), _ctx))

        def begin_setName(self, theName, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_setName.begin(self, ((theName, ), _response, _ex, _sent, _ctx))

        def end_setName(self, _r):
            return _M_omero.model.Screen._op_setName.end(self, _r)

        def getDescription(self, _ctx=None):
            return _M_omero.model.Screen._op_getDescription.invoke(self, ((), _ctx))

        def begin_getDescription(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_getDescription.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDescription(self, _r):
            return _M_omero.model.Screen._op_getDescription.end(self, _r)

        def setDescription(self, theDescription, _ctx=None):
            return _M_omero.model.Screen._op_setDescription.invoke(self, ((theDescription, ), _ctx))

        def begin_setDescription(self, theDescription, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Screen._op_setDescription.begin(self, ((theDescription, ), _response, _ex, _sent, _ctx))

        def end_setDescription(self, _r):
            return _M_omero.model.Screen._op_setDescription.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.ScreenPrx.ice_checkedCast(proxy, '::omero::model::Screen', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.ScreenPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::Screen'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_ScreenPrx = IcePy.defineProxy('::omero::model::Screen', ScreenPrx)

    _M_omero.model._t_Screen = IcePy.declareClass('::omero::model::Screen')

    _M_omero.model._t_Screen = IcePy.defineClass('::omero::model::Screen', Screen, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_type', (), _M_omero._t_RString, False, 0),
        ('_protocolIdentifier', (), _M_omero._t_RString, False, 0),
        ('_protocolDescription', (), _M_omero._t_RString, False, 0),
        ('_reagentSetIdentifier', (), _M_omero._t_RString, False, 0),
        ('_reagentSetDescription', (), _M_omero._t_RString, False, 0),
        ('_plateLinksSeq', (), _M_omero.model._t_ScreenPlateLinksSeq, False, 0),
        ('_plateLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_plateLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0),
        ('_reagentsSeq', (), _M_omero.model._t_ScreenReagentsSeq, False, 0),
        ('_reagentsLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksSeq', (), _M_omero.model._t_ScreenAnnotationLinksSeq, False, 0),
        ('_annotationLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0),
        ('_name', (), _M_omero._t_RString, False, 0),
        ('_description', (), _M_omero._t_RString, False, 0)
    ))
    Screen._ice_type = _M_omero.model._t_Screen

    Screen._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Screen._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Screen._op_getType = IcePy.Operation('getType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Screen._op_setType = IcePy.Operation('setType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Screen._op_getProtocolIdentifier = IcePy.Operation('getProtocolIdentifier', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Screen._op_setProtocolIdentifier = IcePy.Operation('setProtocolIdentifier', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Screen._op_getProtocolDescription = IcePy.Operation('getProtocolDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Screen._op_setProtocolDescription = IcePy.Operation('setProtocolDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Screen._op_getReagentSetIdentifier = IcePy.Operation('getReagentSetIdentifier', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Screen._op_setReagentSetIdentifier = IcePy.Operation('setReagentSetIdentifier', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Screen._op_getReagentSetDescription = IcePy.Operation('getReagentSetDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Screen._op_setReagentSetDescription = IcePy.Operation('setReagentSetDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Screen._op_unloadPlateLinks = IcePy.Operation('unloadPlateLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Screen._op_sizeOfPlateLinks = IcePy.Operation('sizeOfPlateLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Screen._op_copyPlateLinks = IcePy.Operation('copyPlateLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ScreenPlateLinksSeq, False, 0), ())
    Screen._op_addScreenPlateLink = IcePy.Operation('addScreenPlateLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ScreenPlateLink, False, 0),), (), None, ())
    Screen._op_addAllScreenPlateLinkSet = IcePy.Operation('addAllScreenPlateLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ScreenPlateLinksSeq, False, 0),), (), None, ())
    Screen._op_removeScreenPlateLink = IcePy.Operation('removeScreenPlateLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ScreenPlateLink, False, 0),), (), None, ())
    Screen._op_removeAllScreenPlateLinkSet = IcePy.Operation('removeAllScreenPlateLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ScreenPlateLinksSeq, False, 0),), (), None, ())
    Screen._op_clearPlateLinks = IcePy.Operation('clearPlateLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Screen._op_reloadPlateLinks = IcePy.Operation('reloadPlateLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Screen, False, 0),), (), None, ())
    Screen._op_getPlateLinksCountPerOwner = IcePy.Operation('getPlateLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    Screen._op_linkPlate = IcePy.Operation('linkPlate', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Plate, False, 0),), (), ((), _M_omero.model._t_ScreenPlateLink, False, 0), ())
    Screen._op_addScreenPlateLinkToBoth = IcePy.Operation('addScreenPlateLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ScreenPlateLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Screen._op_findScreenPlateLink = IcePy.Operation('findScreenPlateLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Plate, False, 0),), (), ((), _M_omero.model._t_ScreenPlateLinksSeq, False, 0), ())
    Screen._op_unlinkPlate = IcePy.Operation('unlinkPlate', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Plate, False, 0),), (), None, ())
    Screen._op_removeScreenPlateLinkFromBoth = IcePy.Operation('removeScreenPlateLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ScreenPlateLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Screen._op_linkedPlateList = IcePy.Operation('linkedPlateList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ScreenLinkedPlateSeq, False, 0), ())
    Screen._op_unloadReagents = IcePy.Operation('unloadReagents', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Screen._op_sizeOfReagents = IcePy.Operation('sizeOfReagents', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Screen._op_copyReagents = IcePy.Operation('copyReagents', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ScreenReagentsSeq, False, 0), ())
    Screen._op_addReagent = IcePy.Operation('addReagent', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Reagent, False, 0),), (), None, ())
    Screen._op_addAllReagentSet = IcePy.Operation('addAllReagentSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ScreenReagentsSeq, False, 0),), (), None, ())
    Screen._op_removeReagent = IcePy.Operation('removeReagent', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Reagent, False, 0),), (), None, ())
    Screen._op_removeAllReagentSet = IcePy.Operation('removeAllReagentSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ScreenReagentsSeq, False, 0),), (), None, ())
    Screen._op_clearReagents = IcePy.Operation('clearReagents', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Screen._op_reloadReagents = IcePy.Operation('reloadReagents', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Screen, False, 0),), (), None, ())
    Screen._op_unloadAnnotationLinks = IcePy.Operation('unloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Screen._op_sizeOfAnnotationLinks = IcePy.Operation('sizeOfAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Screen._op_copyAnnotationLinks = IcePy.Operation('copyAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ScreenAnnotationLinksSeq, False, 0), ())
    Screen._op_addScreenAnnotationLink = IcePy.Operation('addScreenAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ScreenAnnotationLink, False, 0),), (), None, ())
    Screen._op_addAllScreenAnnotationLinkSet = IcePy.Operation('addAllScreenAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ScreenAnnotationLinksSeq, False, 0),), (), None, ())
    Screen._op_removeScreenAnnotationLink = IcePy.Operation('removeScreenAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ScreenAnnotationLink, False, 0),), (), None, ())
    Screen._op_removeAllScreenAnnotationLinkSet = IcePy.Operation('removeAllScreenAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ScreenAnnotationLinksSeq, False, 0),), (), None, ())
    Screen._op_clearAnnotationLinks = IcePy.Operation('clearAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Screen._op_reloadAnnotationLinks = IcePy.Operation('reloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Screen, False, 0),), (), None, ())
    Screen._op_getAnnotationLinksCountPerOwner = IcePy.Operation('getAnnotationLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    Screen._op_linkAnnotation = IcePy.Operation('linkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_ScreenAnnotationLink, False, 0), ())
    Screen._op_addScreenAnnotationLinkToBoth = IcePy.Operation('addScreenAnnotationLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ScreenAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Screen._op_findScreenAnnotationLink = IcePy.Operation('findScreenAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_ScreenAnnotationLinksSeq, False, 0), ())
    Screen._op_unlinkAnnotation = IcePy.Operation('unlinkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), None, ())
    Screen._op_removeScreenAnnotationLinkFromBoth = IcePy.Operation('removeScreenAnnotationLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ScreenAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Screen._op_linkedAnnotationList = IcePy.Operation('linkedAnnotationList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ScreenLinkedAnnotationSeq, False, 0), ())
    Screen._op_getName = IcePy.Operation('getName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Screen._op_setName = IcePy.Operation('setName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Screen._op_getDescription = IcePy.Operation('getDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Screen._op_setDescription = IcePy.Operation('setDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())

    _M_omero.model.Screen = Screen
    del Screen

    _M_omero.model.ScreenPrx = ScreenPrx
    del ScreenPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero
